/**
 * Class for simple input and output of the following java types.
 * 
 * @author Alexander Stuckenholz (Alexander.Stuckenholz@FernUni-Hagen.de)
 * @version 1.0 - Lastchange 01/06/2004
 */

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

public class InOut extends JDialog implements ActionListener
{
	// internal state
	private int status 				= 0;
	
	// data containers
	private String answerString 	= "";
	private int answerInt 			= 0;
	private char answerChar			= ' ';
	private double answerDouble		= 0;
	private float answerFloat		= 0;
	
	// some gui
	private JPanel readPanel 			= new JPanel();
	private JPanel printPanel 			= new JPanel();
	private JLabel read_label 			= new JLabel();
	private JLabel print_label 			= new JLabel();
	private JLabel print_data 			= new JLabel();
	private JTextField textfield 		= new JTextField();
	private JButton read_button			= new JButton("Ok");
	private JButton print_button		= new JButton("Ok");

	/**
	 * Class constructor.
	 * Prepare both Usesd panels of the dialog and add
	 * action listeners to the buttons.
	 */
	private InOut()
	{
		// create a panel for reading
		this.readPanel.setLayout(new BorderLayout());
		
		// add label, textfield and button to readPanel
		this.readPanel.add(read_label, BorderLayout.NORTH);		
		this.readPanel.add(textfield, BorderLayout.CENTER);
		this.readPanel.add(read_button, BorderLayout.SOUTH);

		// create a panel for reading
		this.printPanel.setLayout(new BorderLayout());
		
		// add label, data-label and button to printPanel
		this.printPanel.add(print_label, BorderLayout.NORTH);
		this.printPanel.add(print_data, BorderLayout.CENTER);
		this.printPanel.add(print_button, BorderLayout.SOUTH);
		
		// add actionListener
		this.read_button.addActionListener(this);
		this.print_button.addActionListener(this);

		// this is a modal Dialog
		this.setModal(true);
	}

	/**
	 * Internal method to display a certain panel.
	 * @param status 	The internal status of the dialog which
	 * 					defines the type of data which will be read or printed.
	 * @param headline	The headline of the dialog.
	 */
	private void showDialog(int status, String headline)
	{
		// init the gui and show the dialog
		this.status = status;
		switch (this.status)
		{
			// Read a string
			case 1 :
				this.read_label.setText(headline);
				this.setContentPane(this.readPanel);
				this.getRootPane().setDefaultButton(this.read_button);
			break;
			// read an int
			case 2 :
				this.read_label.setText(headline);
				this.setContentPane(this.readPanel);
				this.getRootPane().setDefaultButton(this.read_button);
			break;
			// read a char
			case 3 :
				this.read_label.setText(headline);
				this.setContentPane(this.readPanel);
				this.getRootPane().setDefaultButton(this.read_button);
			break;
			// read a double
			case 4 :
				this.read_label.setText(headline);
				this.setContentPane(this.readPanel);
				this.getRootPane().setDefaultButton(this.read_button);
			break;
			// read a float
			case 5 :
				this.read_label.setText(headline);
				this.setContentPane(this.readPanel);
				this.getRootPane().setDefaultButton(this.read_button);
			break;
			// print
			case 6 :
				this.print_label.setText(headline);
				this.setContentPane(this.printPanel);
				this.getRootPane().setDefaultButton(this.print_button);
			break;
		}
		this.pack();
		this.setLocationRelativeTo(null);
		this.show();		
	}

	/**
	 * Read a single String by using the dialog form.
	 * @param headline 	The Headline of the form. 
	 * @return			The String which was entered.
	 */
	public static String readString(String headline)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.showDialog(1, headline);

		// pass the data
		return ea.answerString;
	}

	/**
	 * Read a single String by using the dialog form. Uses a default headline.
	 * @return The String of the form.
	 * @see	#readString(String)
	 */
	public static String readString()
	{
		return InOut.readString("Bitte geben Sie einen String ein");
	}

	/**
	 * Read a single int-value by using the dialog form.
	 * @param headline	The headline of the form.
	 * @return			The int-value.
	 */
	public static int readInt(String headline)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.showDialog(2, headline);

		// pass the data
		return ea.answerInt;
	}

	/**
	 * Read a single int-value by using the dialog form. Uses a default headline.
	 * @return			The int-value.
	 * @see #readInt(String)
	 */
	public static int readInt()
	{
		return InOut.readInt("Bitte geben Sie einen int-Wert ein");
	}

	/**
	 * Read a single char by using the dialog form.
	 * @param headline	The headline of the form.
	 * @return			The char.
	 */
	public static char readChar(String headline)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.showDialog(3, headline);

		// pass the data
		return ea.answerChar;
	}

	/**
	 * Read a single char by using the dialog form. Uses a default headline.
	 * @param headline	The headline of the form.
	 * @return			The char.
	 * @see #readChar(String)
	 */
	public static char readChar()
	{
		return InOut.readChar("Bitte geben Sie ein einzelnes Zeichen ein");
	}

	/**
	 * Read a single double-value by using the dialog form.
	 * @param headline	The headline of the form.
	 * @return			The double-value.
	 */
	public static double readDouble(String headline)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.showDialog(4, headline);

		// pass the data
		return ea.answerDouble;
	}

	/**
	 * Read a single double-value by using the dialog form. Uses a default header.
	 * @param headline	The headline of the form.
	 * @return			The double-value.
	 * @see #readDouble(String)
	 */
	public static double readDouble()
	{
		return InOut.readDouble("Bitte geben Sie einen double-Wert ein");
	}

	/**
	 * Read a single float-value by using the dialog form.
	 * @param headline	The headline of the form.
	 * @return			The float-value.
	 */
	public static float readFloat(String headline)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.showDialog(5, headline);

		// pass the data
		return ea.answerFloat;
	}

	/**
	 * Read a single float-value by using the dialog form. Uses a default header.
	 * @param headline	The headline of the form.
	 * @return			The float-value.
	 * @see #readFloat(String)
	 */
	public static double readFloat()
	{
		return InOut.readDouble("Bitte geben Sie einen float-Wert ein");
	}

	/**
	 * Prints a single String to the dialog form.
	 * @param headline	The headline of the form.
	 * @param out		The String to print out.
	 * @see #readString()
	 */
	public static void print(String headline, String out)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.print_data.setText(out);
		ea.showDialog(6, headline);
	}

	/**
	 * Prints a single String to the dialog form. Uses a default headline.
	 * @param out		The String to print out.
	 * @see #readString()
	 */
	public static void print(String out)
	{
		InOut.print("Der String lautet:", out);
	}

	/**
	 * Prints a single int to the dialog form.
	 * @param headline	The headline of the form.
	 * @param out		The int to print out.
	 * @see #readInt()
	 */
	public static void print(String headline, int out)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.print_data.setText(new Integer(out).toString());
		ea.showDialog(6, headline);
	}

	/**
	 * Prints a single String to the dialog form. Uses a default headline.
	 * @param out		The int to print out.
	 * @see #readInt()
	 */
	public static void print(int out)
	{
		InOut.print("Der int-Wert ist:", out);
	}

	/**
	 * Prints a single char to the dialog form.
	 * @param headline	The headline of the form.
	 * @param out		The char to print out.
	 * @see #readChar()
	 */
	public static void print(String headline, char out)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.print_data.setText(String.valueOf(out));
		ea.showDialog(6, headline);
	}

	/**
	 * Prints a single String to the dialog form. Uses a default header.
	 * @param out		The char to print out.
	 * @see #readChar()
	 */
	public static void print(char out)
	{
		InOut.print("Das Zeichen ist:", out);
	}

	/**
	 * Prints a single double to the dialog form.
	 * @param headline	The headline of the form.
	 * @param out		The double to print out.
	 * @see #readDouble()
	 */
	public static void print(String headline, double out)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.print_data.setText(new Double(out).toString());
		ea.showDialog(6, headline);
	}

	/**
	 * Prints a single double to the dialog form. Uses a default header.
	 * @param out		The double to print out.
	 * @see #readDouble()
	 */
	public static void print(double out)
	{
		InOut.print("Der double-Wert ist:", out);
	}

	/**
	 * Prints a single float to the dialog form.
	 * @param headline	The headline of the form.
	 * @param out		The float to print out.
	 * @see #readFloat()
	 */
	public static void print(String headline, float out)
	{
		// create a new Object
		InOut ea = new InOut();
		
		// init the gui and show
		ea.print_data.setText(new Float(out).toString());
		ea.showDialog(6, headline);
	}

	/**
	 * Prints a single float to the dialog form. Uses a default header.
	 * @param out		The float to print out.
	 * @see #readFloat()
	 */
	public static void print(float out)
	{
		InOut.print("Der double-Wert ist:", out);
	}

	/**
	 * Internal method to catch the button-click-event.
	 * Checks the data in the textfield, converts it to the
	 * destination type and disposes the form. Prints out an
	 * error message if conversion fails.
	 */
	public void actionPerformed(ActionEvent event)
	{
		if (this.status == 1)
		{
			// save the String and close the dialog
			this.answerString = this.textfield.getText();
			this.dispose();
		}
		else if (this.status == 2)
		{
			try
			{
				// check if this is an int, save it and close the dialog 
				this.answerInt = Integer.parseInt(this.textfield.getText());
				this.dispose();
			}
			catch (Exception e)
			{
				JOptionPane.showMessageDialog(this, "Bei den eingegebenen Daten handelt es sich nicht um einen int-Wert!", "Achtung", JOptionPane.ERROR_MESSAGE);
			}
		}
		else if (this.status == 3)
		{
			if (this.textfield.getText().length() == 1)
			{
				// check if this is a char, save it and close the dialog
				this.answerChar = this.textfield.getText().charAt(0);
				this.dispose();
			}
			else
			{
				JOptionPane.showMessageDialog(this, "Bitte geben Sie nur ein einzelnes Zeichen ein!", "Achtung", JOptionPane.ERROR_MESSAGE);
			}
		}
		else if (this.status == 4)
		{
			try
			{
				// check if this is an double, save it and close the dialog 
				this.answerDouble = Double.parseDouble(this.textfield.getText());
				this.dispose();
			}
			catch (Exception e)
			{
				JOptionPane.showMessageDialog(this, "Bei den eingegebenen Daten handelt es sich nicht um einen double-Wert!", "Achtung", JOptionPane.ERROR_MESSAGE);
			}
		}
		else if (this.status == 4)
		{
			try
			{
				// check if this is an float, save it and close the dialog 
				this.answerDouble = Float.parseFloat(this.textfield.getText());
				this.dispose();
			}
			catch (Exception e)
			{
				JOptionPane.showMessageDialog(this, "Bei den eingegebenen Daten handelt es sich nicht um einen float-Wert!", "Achtung", JOptionPane.ERROR_MESSAGE);
			}
		}
		else
		{
			this.dispose();
		}
	}
}